# LightCNN

Fast and accurate face recognition model optimized for Central Asian faces.

## GitHub
For full documentation, examples, and source code:
https://github.com/YernarBekbolat/LightCNN-V4-PyTorch 